@@ -33,7 +33,6 @@ from .model_core import (
 from .sync_schemas import _get_all_values
 from .trial_metadata import (
     cimac_id_regex,
-    ClinicalTrial,
     CollectionEvent,
     Participant,
     Sample,
@@ -102,7 +101,7 @@ def _get_upload_type(samples: Iterable[Dict[str, Any]]) -> str:
 def _get_and_check(
     obj: Union[Dict[str, Any], List[Dict[str, Any]]],
     key: str,
-    msg: Callable[[Any], str],
+    msg: str,
     default: Any = None,
     check: Callable[[Any], bool] = bool,
 ) -> Any:
@@ -124,7 +123,7 @@ def _get_and_check(
 
 
 def _extract_info_from_manifest(
-    manifest: Dict[str, Any], *, session: Session
+    manifest: Dict[str, Any]
 ) -> Tuple[str, str, List[Dict[str, Any]]]:
     """
     Given a manifest, do initial validation and return some key values
@@ -295,7 +294,7 @@ def _convert_samples(
 @with_default_session
 def insert_manifest_into_blob(
     manifest: Dict[str, Any], uploader_email: str, *, session: Session
-):
+) -> None:
     """
     Given a CSMS-style manifest, add it into the JSON metadata blob
     
@@ -324,10 +323,8 @@ def insert_manifest_into_blob(
     # schemas import here to keep JSON-blob code together
     from cidc_schemas.prism.merger import merge_clinical_trial_metadata
 
-    trial_id, manifest_id, samples = _extract_info_from_manifest(
-        manifest, session=session
-    )
-    trial_md = TrialMetadata.select_for_update_by_trial_id(trial_id)
+    trial_id, manifest_id, samples = _extract_info_from_manifest(manifest)
+    trial_md = TrialMetadata.select_for_update_by_trial_id(trial_id, session=session)
     if manifest_id in [s["manifest_id"] for s in trial_md.metadata_json["shipments"]]:
         raise Exception(
             f"Manifest with manifest_id={manifest_id} already exists for trial {trial_id}"
@@ -385,7 +382,7 @@ def insert_manifest_into_blob(
         raise Exception({"prism errors": [str(e) for e in errs]})
 
     # save it
-    trial_md.update(changes={"metadata_json": merged})
+    trial_md.update(changes={"metadata_json": merged}, session=session)
 
     # create pseudo-UploadJobs
     UploadJobs(
@@ -395,17 +392,15 @@ def insert_manifest_into_blob(
         metadata_patch=patch,
         upload_type=_get_upload_type(samples),
         uploader_email=uploader_email,
-    ).insert()
+    ).insert(session=session)
 
 
 @with_default_session
 def insert_manifest_from_json(
     manifest: Dict[str, Any], uploader_email: str, *, session: Session
-) -> List[Exception]:
+) -> None:
     """
     Given a CSMS-style manifest, validate and add it into the relational tables.
-
-    Returns errors
     
     Exceptions Raised
     -----------------
@@ -430,11 +425,9 @@ def insert_manifest_from_json(
     - "No Collection event with trial_id, event_name = {trial_id}, {event_name}; needed for sample {cimac_id} on manifest {manifest_id}"
     - "Multiple errors: [{errors from insert_record_batch}]"
     """
-    trial_id, manifest_id, samples = _extract_info_from_manifest(
-        manifest, session=session
-    )
+    trial_id, manifest_id, samples = _extract_info_from_manifest(manifest)
     # validate that trial exists in the JSON json or error otherwise
-    _ = TrialMetadata.select_for_update_by_trial_id(trial_id)
+    _ = TrialMetadata.select_for_update_by_trial_id(trial_id, session=session)
 
     if (
         session.query(Shipment)
@@ -477,7 +470,7 @@ def insert_manifest_from_json(
     ordered_records[Sample] = []
     for cimac_participant_id, partic_samples in sample_map.items():
         # add the participant if they don't already exist
-        partic = Participant.get_by_id(trial_id, cimac_participant_id)
+        partic = Participant.get_by_id(trial_id, cimac_participant_id, session=session)
         if partic is None and not any(
             # check if we're already going to add it
             [
@@ -719,13 +712,11 @@ def _initial_manifest_validation(csms_manifest: Dict[str, Any], *, session: Sess
     - f"No assay_priority defined for manifest_id={manifest_id} for trial {trial_id}"
     - f"No assay_type defined for manifest_id={manifest_id} for trial {trial_id}"
     """
+    trial_id, manifest_id, csms_samples = _extract_info_from_manifest(csms_manifest)
     # ----- Get all our information together -----
-    csms_manifest["trial_id"] = csms_manifest.pop("protocol_identifier")
-    trial_id, manifest_id, csms_samples = _extract_info_from_manifest(
-        csms_manifest, session=session
-    )
+    csms_manifest["trial_id"] = trial_id
     # validate that trial exists in the JSON json or error otherwise
-    _ = TrialMetadata.select_for_update_by_trial_id(trial_id)
+    _ = TrialMetadata.select_for_update_by_trial_id(trial_id, session=session)
 
     cidc_shipment = (
         session.query(Shipment).filter(Shipment.manifest_id == manifest_id).first()
